

.. _linear_dimension_api:

---------------
LinearDimension
---------------

.. currentmodule:: csdmpy.dimensions.linear

.. autoclass:: LinearDimension
    :show-inheritance:

    .. rubric:: Attributes Summary

    .. autosummary::
        ~LinearDimension.increment
        ~LinearDimension.complex_fft

    .. rubric:: Attributes Documentation

    .. autoattribute:: increment
    .. autoattribute:: complex_fft
